==> bibledit-0.5.tar.gz: bibledit-0.5/src/dialogreplace.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGREPLACE_H
#define INCLUDED_DIALOGREPLACE_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"


class ReplaceDialog
{
public:
  ReplaceDialog (const string& projectname,
                 const vector <string>& references_in,
                 const ustring& searchword, const ustring& replaceword);
  virtual ~ ReplaceDialog ();
  virtual int run ();
  void on_yesbutton_clicked ();
  void on_nobutton_clicked ();
  void on_allbutton_clicked ();
  void on_cancelbutton_clicked ();
protected:
private:
  GtkWidget *replacedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *referencelabel;
  GtkWidget *vbox1;
  GtkWidget *label1;
  GtkWidget *scrolledwindow4;
  GtkWidget *textview1;
  GtkWidget *label2;
  GtkWidget *scrolledwindow5;
  GtkWidget *textview2;
  GtkWidget *hbox3;
  GtkWidget *yesbutton;
  GtkWidget *nobutton;
  GtkWidget *allbutton;
  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image1;
  GtkWidget *label3;
  GtkWidget *cancelbutton;
  GtkWidget *dialog_action_area1;
  vector < string > references;
  unsigned int referencepointer;
  void set_gui ();
  void accept_change ();
  Scripture scripture;
  ustring searchfor;
  ustring replacewith;
};


#endif

==> bibledit-0.7.tar.gz: bibledit-0.7/src/dialogreplace.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGREPLACE_H
#define INCLUDED_DIALOGREPLACE_H


#include <gtk/gtk.h>
#include "configuration.h"
#include <set>


class ReplaceDialog
{
public:
  ReplaceDialog (Configuration* configuration);
  virtual ~ ReplaceDialog ();
  virtual int run ();
  vector <string> results;
  bool is_indexing;
protected:
private:
  GtkWidget *replacedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *table1;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *entry2;
  GtkWidget *entry3;
  GtkWidget *checkbutton1;
  GtkWidget *selectbutton;
  GtkWidget *alignment1;
  GtkWidget *hbox1;
  GtkWidget *image1;
  GtkWidget *label9;
  GtkWidget *dialog_action_area1;
  GtkWidget *buttonfind;
  GtkWidget *buttoncancel;
  Configuration *myconfiguration;
  vector <string> selectable_books;
  set <string> selected_books;
  static void replacedialog_on_buttonfind_clicked (GtkButton *button, gpointer user_data);
  void on_buttonfind_clicked ();
  static void on_selectbutton_clicked (GtkButton *button, gpointer user_data);
  void on_selectbutton_clicked2 ();
};


#endif
